/*******************************************************************************
* File Name: OpampA.c
* Version 1.90
*
* Description:
*  This file provides the source code to the API for OpAmp (Analog Buffer) 
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "OpampA.h"

uint8 OpampA_initVar = 0u;


/*******************************************************************************   
* Function Name: OpampA_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  OpampA_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OpampA_Init(void) 
{
    OpampA_SetPower(OpampA_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: OpampA_Enable
********************************************************************************
*
* Summary:
*  Enables the OpAmp block operation
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OpampA_Enable(void) 
{
    /* Enable negative charge pumps in ANIF */
    OpampA_PUMP_CR1_REG  |= (OpampA_PUMP_CR1_CLKSEL | OpampA_PUMP_CR1_FORCE);

    /* Enable power to buffer in active mode */
    OpampA_PM_ACT_CFG_REG |= OpampA_ACT_PWR_EN;

    /* Enable power to buffer in alternative active mode */
    OpampA_PM_STBY_CFG_REG |= OpampA_STBY_PWR_EN;
}


/*******************************************************************************
* Function Name:   OpampA_Start
********************************************************************************
*
* Summary:
*  The start function initializes the Analog Buffer with the default values and 
*  sets the power to the given level. A power level of 0, is same as 
*  executing the stop function.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  OpampA_initVar: Used to check the initial configuration, modified 
*  when this function is called for the first time.
*
*******************************************************************************/
void OpampA_Start(void) 
{
    if(OpampA_initVar == 0u)
    {
        OpampA_initVar = 1u;
        OpampA_Init();
    }

    OpampA_Enable();
}


/*******************************************************************************
* Function Name: OpampA_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OpampA_Stop(void) 
{
    /* Disable power to buffer in active mode template */
    OpampA_PM_ACT_CFG_REG &= (uint8)(~OpampA_ACT_PWR_EN);

    /* Disable power to buffer in alternative active mode template */
    OpampA_PM_STBY_CFG_REG &= (uint8)(~OpampA_STBY_PWR_EN);
    
    /* Disable negative charge pumps for ANIF only if all ABuf is turned OFF */
    if(OpampA_PM_ACT_CFG_REG == 0u)
    {
        OpampA_PUMP_CR1_REG &= (uint8)(~(OpampA_PUMP_CR1_CLKSEL | OpampA_PUMP_CR1_FORCE));
    }
}


/*******************************************************************************
* Function Name: OpampA_SetPower
********************************************************************************
*
* Summary:
*  Sets power level of Analog buffer.
*
* Parameters: 
*  power: PSoC3: Sets power level between low (1) and high power (3).
*         PSoC5: Sets power level High (0)
*
* Return:
*  void
*
**********************************************************************************/
void OpampA_SetPower(uint8 power) 
{
    #if (CY_PSOC3 || CY_PSOC5LP)
        OpampA_CR_REG &= (uint8)(~OpampA_PWR_MASK);
        OpampA_CR_REG |= power & OpampA_PWR_MASK;      /* Set device power */
    #else
        CYASSERT(OpampA_HIGHPOWER == power);
    #endif /* CY_PSOC3 || CY_PSOC5LP */
}


/* [] END OF FILE */
