/*******************************************************************************
* File Name: OpampB.c
* Version 1.90
*
* Description:
*  This file provides the source code to the API for OpAmp (Analog Buffer) 
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "OpampB.h"

uint8 OpampB_initVar = 0u;


/*******************************************************************************   
* Function Name: OpampB_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the 
*  customizer of the component placed onto schematic. Usually called in 
*  OpampB_Start().
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OpampB_Init(void) 
{
    OpampB_SetPower(OpampB_DEFAULT_POWER);
}


/*******************************************************************************   
* Function Name: OpampB_Enable
********************************************************************************
*
* Summary:
*  Enables the OpAmp block operation
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OpampB_Enable(void) 
{
    /* Enable negative charge pumps in ANIF */
    OpampB_PUMP_CR1_REG  |= (OpampB_PUMP_CR1_CLKSEL | OpampB_PUMP_CR1_FORCE);

    /* Enable power to buffer in active mode */
    OpampB_PM_ACT_CFG_REG |= OpampB_ACT_PWR_EN;

    /* Enable power to buffer in alternative active mode */
    OpampB_PM_STBY_CFG_REG |= OpampB_STBY_PWR_EN;
}


/*******************************************************************************
* Function Name:   OpampB_Start
********************************************************************************
*
* Summary:
*  The start function initializes the Analog Buffer with the default values and 
*  sets the power to the given level. A power level of 0, is same as 
*  executing the stop function.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  OpampB_initVar: Used to check the initial configuration, modified 
*  when this function is called for the first time.
*
*******************************************************************************/
void OpampB_Start(void) 
{
    if(OpampB_initVar == 0u)
    {
        OpampB_initVar = 1u;
        OpampB_Init();
    }

    OpampB_Enable();
}


/*******************************************************************************
* Function Name: OpampB_Stop
********************************************************************************
*
* Summary:
*  Powers down amplifier to lowest power state.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void OpampB_Stop(void) 
{
    /* Disable power to buffer in active mode template */
    OpampB_PM_ACT_CFG_REG &= (uint8)(~OpampB_ACT_PWR_EN);

    /* Disable power to buffer in alternative active mode template */
    OpampB_PM_STBY_CFG_REG &= (uint8)(~OpampB_STBY_PWR_EN);
    
    /* Disable negative charge pumps for ANIF only if all ABuf is turned OFF */
    if(OpampB_PM_ACT_CFG_REG == 0u)
    {
        OpampB_PUMP_CR1_REG &= (uint8)(~(OpampB_PUMP_CR1_CLKSEL | OpampB_PUMP_CR1_FORCE));
    }
}


/*******************************************************************************
* Function Name: OpampB_SetPower
********************************************************************************
*
* Summary:
*  Sets power level of Analog buffer.
*
* Parameters: 
*  power: PSoC3: Sets power level between low (1) and high power (3).
*         PSoC5: Sets power level High (0)
*
* Return:
*  void
*
**********************************************************************************/
void OpampB_SetPower(uint8 power) 
{
    #if (CY_PSOC3 || CY_PSOC5LP)
        OpampB_CR_REG &= (uint8)(~OpampB_PWR_MASK);
        OpampB_CR_REG |= power & OpampB_PWR_MASK;      /* Set device power */
    #else
        CYASSERT(OpampB_HIGHPOWER == power);
    #endif /* CY_PSOC3 || CY_PSOC5LP */
}


/* [] END OF FILE */
